@@ -374,7 +374,14 @@ class PatientData:
         """
         self.cfg = cfg
 
-        summary_filename = glob.glob(path.join(self.cfg.data_path, "*summary.txt"))[0]
+        glob_path = path.join(path.abspath(self.cfg.data_path), "*summary.txt")
+        summary_glob = glob.glob(glob_path)
+        print(summary_glob)
+        if summary_glob:
+            summary_filename = summary_glob[0]
+        else:
+            raise ValueError(f"Summary file not found: {glob_path}")
+
         self.cfg.summary = helpers.parse_chb_summary(summary_filename)
 
         self.seizures_time = []
