@@ -3,11 +3,14 @@ import tensorflow as tf
 
 # From Tensorflow-Addons
 class FBetaScore(tf.keras.metrics.Metric):
-    """Computes F-Beta score. It is the weighted harmonic mean of precision and
+    """Computes F-Beta score.
+    
+    It is the weighted harmonic mean of precision and
     recall. Output range is [0, 1]. Works for both multi-class and multi-label
     classification.
 
     F-Beta = (1 + beta^2) * (prec * recall) / ((beta^2 * prec) + recall)
+
     Args:
         num_classes: Number of unique classes in the dataset.
         average: Type of averaging to be performed on data.
@@ -19,18 +22,21 @@ class FBetaScore(tf.keras.metrics.Metric):
         threshold: Elements of `y_pred` greater than threshold are
             converted to be 1, and the rest 0. If threshold is
             None, the argmax is converted to 1, and the rest 0.
+
     Returns:
         F-Beta Score: float
+
     Raises:
         ValueError: If the `average` has values other than
         [None, micro, macro, weighted].
         ValueError: If the `beta` value is less than or equal
         to 0.
+
     `average` parameter behavior:
         None: Scores for each class are returned
-        micro: True positivies, false positives and
+        micro: True positives, false positives and
             false negatives are computed globally.
-        macro: True positivies, false positives and
+        macro: True positives, false positives and
             false negatives are computed for each class
             and their unweighted mean is returned.
         weighted: Metrics are computed for each class
@@ -41,7 +47,7 @@ class FBetaScore(tf.keras.metrics.Metric):
     def __init__(
         self,
         num_classes,
-        average="macro",
+        average="None",
         beta=1.0,
         threshold=None,
         name="fbeta_score",
@@ -184,9 +190,9 @@ class Precision(tf.keras.metrics.Metric):
         to 0.
     `average` parameter behavior:
         None: Scores for each class are returned
-        micro: True positivies, false positives and
+        micro: True positives, false positives and
             false negatives are computed globally.
-        macro: True positivies, false positives and
+        macro: True positives, false positives and
             false negatives are computed for each class
             and their unweighted mean is returned.
         weighted: Metrics are computed for each class
@@ -332,9 +338,9 @@ class Recall(tf.keras.metrics.Metric):
         to 0.
     `average` parameter behavior:
         None: Scores for each class are returned
-        micro: True positivies, false positives and
+        micro: True positives, false positives and
             false negatives are computed globally.
-        macro: True positivies, false positives and
+        macro: True positives, false positives and
             false negatives are computed for each class
             and their unweighted mean is returned.
         weighted: Metrics are computed for each class
@@ -455,11 +461,14 @@ class Recall(tf.keras.metrics.Metric):
 
 # From Tensorflow-Addons
 class F1Score(FBetaScore):
-    """Computes F-1 Score. It is the harmonic mean of precision and recall.
+    """Computes F-1 Score.
+    
+    It is the harmonic mean of precision and recall.
     Output range is [0, 1]. Works for both multi-class and multi-label
     classification.
 
     F-1 = 2 * (precision * recall) / (precision + recall)
+    
     Args:
         num_classes: Number of unique classes in the dataset.
         average: Type of averaging to be performed on data.
@@ -475,9 +484,9 @@ class F1Score(FBetaScore):
         [None, micro, macro, weighted].
     `average` parameter behavior:
         None: Scores for each class are returned
-        micro: True positivies, false positives and
+        micro: True positives, false positives and
             false negatives are computed globally.
-        macro: True positivies, false positives and
+        macro: True positives, false positives and
             false negatives are computed for each class
             and their unweighted mean is returned.
         weighted: Metrics are computed for each class
@@ -488,7 +497,7 @@ class F1Score(FBetaScore):
     def __init__(
         self,
         num_classes,
-        average="macro",
+        average="None",
         threshold=None,
         name="macro_average_f1-score",
         dtype=tf.float32,
