@@ -7,9 +7,7 @@ import pandas as pd
 from .data_loader import load_data_from_config
 
 
-def get_dataset(
-    config, verbose=0
-):
+def get_dataset(config, verbose=0):
 
     print("--------------------------")
     print("Getting dataset")
@@ -19,8 +17,5 @@ def get_dataset(
     # 1.1. Loading data
     ##########################################
     features, labels, label_names, nb_classes = load_data_from_config(config)
-    
 
     return features, labels, label_names, nb_classes
-
-
